@@ -9,28 +9,33 @@ from io import BufferedIOBase
 Essentially static class variables
 '''
 
-def Property(func):
-    '''Wrapper for static properties for `Handler`'''
-    @property
-    def wrapper(self):
-        return getattr(self,'_' + func.__name__)
-    @wrapper.setter
-    def wrapper(self,value):
-        return setattr(self,'_' + func.__name__,value)
-    return wrapper
-
 # The default request version.  This only affects responses up until
 # the point where the request line is parsed, so it mainly decides what
 # the client gets back when sending a malformed request line.
 # Most web servers default to HTTP 0.9, i.e. don't send a status line.
 default_request_version = "HTTP/0.9"
 
-class RequestHandler(StreamRequestHandler):
+class Request(StreamRequestHandler):
+    '''Base HTTP handler'''
+    """
+    Base properties
     """
-    Modified version of Python's internal HTTP/1.1 Compatiable `BaseHTTPHandler`
 
-    Modifications had been made to prettify the code and to fix some annoying stuff ;)
-    """
+    wfile : BufferedIOBase
+    '''`BufferedIOBase` like I/O for writing messages to sockets'''
+
+    rfile : BufferedIOBase
+    '''`BufferedIOBase` like I/O for reading messages from sockets'''
+    
+    headers : client.HTTPMessage
+    '''Contains parsed headers'''        
+
+    command : str
+    '''The request command (GET,POST,etc)'''
+
+    raw_requestline : str
+    '''Raw `HTTP` request line of the request'''
+
     def __init__(self, request, client_address, server):
         '''The `server`,which is what instantlizes this handler,must have `__handle__` method
         which takes 1 argument (for the handler itself) 
@@ -42,7 +47,7 @@ class RequestHandler(StreamRequestHandler):
         # Set this to HTTP/1.1 to enable automatic keepalive
         self.protocol_version = server.protocol_version
         # Error page formats
-        self.error_message_format = server.error_message_format
+        self.format_error_message = server.format_error_message
         # hack to maintain backwards compatibility
         self.responses = {
             v: (v.phrase, v.description)
@@ -223,8 +228,9 @@ class RequestHandler(StreamRequestHandler):
             message = shortmsg
         if explain is None:
             explain = longmsg
-        self.log_error("HTTP %d -- %s", code, message)
-        self.send_response(code, message)
+        self.log_error("HTTP %d -- %s", code, explain)
+        self.clear_header()
+        self.send_response_only(code, message)
         self.send_header('Connection', 'close')
 
         # Message body is omitted for cases described in:
@@ -237,11 +243,12 @@ class RequestHandler(StreamRequestHandler):
                          HTTPStatus.NOT_MODIFIED)):
             # HTML encode to prevent Cross Site Scripting attacks
             # (see bug #1100201)
-            content = (self.error_message_format % {
-                'code': code,
-                'message': escape(message, quote=False),
-                'explain': escape(explain, quote=False)
-            })
+            content = self.format_error_message(
+                code   =code,
+                message=escape(message, quote=False),
+                explain=escape(explain, quote=False),
+                request=self
+            )
             body = content.encode('UTF-8', 'replace')
             self.send_header("Content-Type", 'text/html;charset=utf-8')
             self.send_header('Content-Length', str(len(body)))
@@ -270,13 +277,15 @@ class RequestHandler(StreamRequestHandler):
             self._headers_buffer = [("%s %d %s\r\n" % (self.protocol_version, code, message)).encode('utf-8')] + self._headers_buffer
             # Always send this at the begining
     
+    def clear_header(self):
+        self._headers_buffer = []
+
     def send_header(self, keyword, value):
         """Send a MIME header to the headers buffer."""
         if self.request_version != 'HTTP/0.9':
             if not hasattr(self, '_headers_buffer'):
                 self._headers_buffer = []
-            self._headers_buffer.append(
-                ("%s: %s\r\n" % (keyword, value)).encode('utf-8'))
+            self._headers_buffer.append(("%s: %s\r\n" % (keyword, value)).encode('utf-8'))
 
         if keyword.lower() == 'connection':
             if value.lower() == 'close':
@@ -293,6 +302,8 @@ class RequestHandler(StreamRequestHandler):
 
     def flush_headers(self):
         if hasattr(self, '_headers_buffer'):
+            if not self.protocol_version in self._headers_buffer[0].decode():
+                raise Exception('Request was not responed with `requst.send_response`.')
             self.wfile.write(b"".join(self._headers_buffer))
             self._headers_buffer = []
 
@@ -369,34 +380,7 @@ class RequestHandler(StreamRequestHandler):
         """
         self.logger.info(self.format_log(format,*args))
     
-    """
-    Properties.These funtions do nothing but providing documents
-    and will be overriden
-    """
-    @Property
-    def wfile(self) -> BufferedIOBase:
-        '''`BufferedIOBase` like I/O for writing messages to sockets'''
-        pass
 
-    @Property
-    def rfile(self) -> BufferedIOBase:
-        '''`BufferedIOBase` like I/O for reading messages from sockets'''
-        pass
-
-    @Property
-    def headers(self) -> client.HTTPMessage:
-        '''Contains parsed headers'''
-        pass
-
-    @Property
-    def command(self) -> str:
-        '''The request command (GET,POST,etc)'''
-        pass
-
-    @Property
-    def raw_requestline(self) -> str:
-        '''Raw `HTTP` request line of the request'''
-        pass
 
 import os
 __all__ = [i[:-3] for i in os.listdir(os.path.dirname(__file__)) if i[-2:] == 'py' and i != '__init__.py']
